@@ -1,8 +1,8 @@
-from .base import WaveformModel
-
+import numpy as np
 import torch
 import torch.nn as nn
-import numpy as np
+
+from .base import WaveformModel
 
 
 class BasicPhaseAE(WaveformModel):
@@ -10,6 +10,8 @@ class BasicPhaseAE(WaveformModel):
     Simple AutoEncoder network architecture to pick P-/S-phases,
     from Woollam et al., (2019).
 
+    .. document_args:: seisbench.models BasicPhaseAE
+
     :param in_channels: Number of input channels, by default 3.
     :type in_channels: int
     :param in_samples: Number of input samples per channel, by default 600.
@@ -24,6 +26,10 @@ class BasicPhaseAE(WaveformModel):
     :param kwargs: Keyword arguments passed to the constructor of :py:class:`WaveformModel`.
     """
 
+    _annotate_args = WaveformModel._annotate_args.copy()
+    _annotate_args["*_threshold"] = ("Detection threshold for the provided phase", 0.3)
+    _annotate_args["overlap"] = (_annotate_args["overlap"][0], 300)
+
     def __init__(
         self, in_channels=3, classes=3, phases="NPS", sampling_rate=100, **kwargs
     ):
@@ -39,7 +45,6 @@ class BasicPhaseAE(WaveformModel):
             citation=citation,
             in_samples=600,
             output_type="array",
-            default_args={"overlap": 300},
             pred_sample=(0, 600),
             labels=phases,
             sampling_rate=sampling_rate,
@@ -76,7 +81,7 @@ class BasicPhaseAE(WaveformModel):
         self.out = nn.ConvTranspose1d(12, self.classes, self.kernel_size, padding=2)
         self.softmax = torch.nn.Softmax(dim=1)
 
-    def forward(self, x):
+    def forward(self, x, logits=False):
 
         x_l1 = self.activation(self.conv2(self.activation(self.conv1(x))))
         x_l2 = self.drop1(self.activation(self.conv3(x_l1)))
@@ -86,9 +91,12 @@ class BasicPhaseAE(WaveformModel):
         x_r2 = self.upsample3(self.activation(self.conv6(x_r3)))
         x_r1 = self.upsample4(self.activation(self.conv7(x_r2)))
 
-        x_out = self.softmax(self.out(x_r1))
+        x_out = self.out(x_r1)
 
-        return x_out
+        if logits:
+            return x_out
+        else:
+            return self.softmax(x_out)
 
     def annotate_window_pre(self, window, argdict):
         # Add a demean and normalize step to the preprocessing
@@ -122,7 +130,9 @@ class BasicPhaseAE(WaveformModel):
 
             picks += self.picks_from_annotations(
                 annotations.select(channel=f"BasicPhaseAE_{phase}"),
-                argdict.get(f"{phase}_threshold", 0.3),
+                argdict.get(
+                    f"{phase}_threshold", self._annotate_args.get("*_threshold")[1]
+                ),
                 phase,
             )
 
