@@ -1,18 +1,24 @@
-from .base import WaveformModel
-
+import numpy as np
 import torch
 import torch.nn as nn
 import torch.nn.functional as F
 from scipy.signal import stft
-import numpy as np
+
+from .base import WaveformModel
 
 
 class CRED(WaveformModel):
     """
     Note: There are subtle differences between the model presented in the paper (as in Figure 1) and the code on Github.
           Here we follow the implementation from Github to allow for compatibility with the pretrained weights.
+
+    .. document_args:: seisbench.models CRED
     """
 
+    _annotate_args = WaveformModel._annotate_args.copy()
+    _annotate_args["detection_threshold"] = ("Detection threshold", 0.5)
+    _annotate_args["overlap"] = (_annotate_args["overlap"][0], 1500)
+
     def __init__(
         self,
         in_samples=3000,
@@ -34,7 +40,6 @@ class CRED(WaveformModel):
             in_samples=in_samples,
             output_type="array",
             pred_sample=(0, in_samples),
-            default_args={"overlap": 500},
             **kwargs,
         )
 
@@ -53,7 +58,7 @@ class CRED(WaveformModel):
         self.norm2 = nn.BatchNorm1d(64, eps=1e-3)
         self.fc2 = nn.Linear(64, 1)
 
-    def forward(self, x):
+    def forward(self, x, logits=False):
         x = torch.relu(self.conv1(x))
         x = self.cnn_block1(x) + x
 
@@ -92,10 +97,16 @@ class CRED(WaveformModel):
         shape_save = x.shape
         x = x.reshape((-1,) + x.shape[2:])
         x = self.dropout(x)
-        x = torch.sigmoid(self.fc2(x))
-        x = x.reshape(shape_save[:2] + (1,))
 
-        return x
+        if logits:
+            x = self.fc2(x)
+            x = x.reshape(shape_save[:2] + (1,))
+            return x
+
+        else:
+            x = torch.sigmoid(self.fc2(x))
+            x = x.reshape(shape_save[:2] + (1,))
+            return x
 
     @staticmethod
     def waveforms_to_spectrogram(wv):
@@ -125,7 +136,9 @@ class CRED(WaveformModel):
         """
         detections = self.detections_from_annotations(
             annotations.select(channel="CRED_Detection"),
-            argdict.get("detection_threshold", 0.5),
+            argdict.get(
+                "detection_threshold", self._annotate_args.get("detection_threshold")[1]
+            ),
         )
 
         return detections
