@@ -1,16 +1,17 @@
-from .base import WaveformModel, ActivationLSTMCell, CustomLSTM
+import warnings
 
+import numpy as np
 import torch
 import torch.nn as nn
 import torch.nn.functional as F
-import numpy as np
-import warnings
+
+from .base import ActivationLSTMCell, CustomLSTM, WaveformModel
 
 
 # For implementation, potentially follow: https://medium.com/huggingface/from-tensorflow-to-pytorch-265f40ef2a28
 class EQTransformer(WaveformModel):
     """
-    The EQTranformer from Mousavi et al. (2020)
+    The EQTransformer from Mousavi et al. (2020)
 
     Implementation adapted from the Github repository https://github.com/smousavi05/EQTransformer
     Assumes padding="same" and activation="relu" as in the pretrained EQTransformer models
@@ -18,6 +19,8 @@ class EQTransformer(WaveformModel):
     By instantiating the model with `from_pretrained("original")` a binary compatible version of the original
     EQTransformer with the original weights from Mousavi et al. (2020) can be loaded.
 
+    .. document_args:: seisbench.models EQTransformer
+
     :param in_channels: Number of input channels, by default 3.
     :param in_samples: Number of input samples per channel, by default 6000.
                        The model expects input shape (in_channels, in_samples)
@@ -35,6 +38,21 @@ class EQTransformer(WaveformModel):
     :param kwargs: Keyword arguments passed to the constructor of :py:class:`WaveformModel`.
     """
 
+    _annotate_args = WaveformModel._annotate_args.copy()
+    _annotate_args["*_threshold"] = ("Detection threshold for the provided phase", 0.1)
+    _annotate_args["detection_threshold"] = ("Detection threshold", 0.3)
+    _annotate_args["blinding"] = (
+        "Number of prediction samples to discard on each side of each window prediction",
+        (500, 500),
+    )
+    # Overwrite default stacking method
+    _annotate_args["stacking"] = (
+        "Stacking method for overlapping windows (only for window prediction models). "
+        "Options are 'max' and 'avg'. ",
+        "max",
+    )
+    _annotate_args["overlap"] = (_annotate_args["overlap"][0], 3000)
+
     def __init__(
         self,
         in_channels=3,
@@ -59,7 +77,6 @@ class EQTransformer(WaveformModel):
         super().__init__(
             citation=citation,
             output_type="array",
-            default_args={"overlap": 1800, "blinding": (500, 500)},
             in_samples=in_samples,
             pred_sample=(0, in_samples),
             labels=["Detection"] + list(phases),
@@ -191,7 +208,7 @@ class EQTransformer(WaveformModel):
         self.pick_decoders = nn.ModuleList(self.pick_decoders)
         self.pick_convs = nn.ModuleList(self.pick_convs)
 
-    def forward(self, x):
+    def forward(self, x, logits=False):
         assert x.ndim == 3
         assert x.shape[1:] == (self.in_channels, self.in_samples)
 
@@ -204,7 +221,10 @@ class EQTransformer(WaveformModel):
 
         # Detection part
         detection = self.decoder_d(x)
-        detection = torch.sigmoid(self.conv_d(detection))
+        if logits:
+            detection = self.conv_d(detection)
+        else:
+            detection = torch.sigmoid(self.conv_d(detection))
         detection = torch.squeeze(detection, dim=1)  # Remove channel dimension
 
         outputs = [detection]
@@ -223,7 +243,10 @@ class EQTransformer(WaveformModel):
             )  # From sequence, batch, channels to batch, channels, sequence
             px, _ = attention(px)
             px = decoder(px)
-            pred = torch.sigmoid(conv(px))
+            if logits:
+                pred = conv(px)
+            else:
+                pred = torch.sigmoid(conv(px))
             pred = torch.squeeze(pred, dim=1)  # Remove channel dimension
 
             outputs.append(pred)
@@ -232,7 +255,9 @@ class EQTransformer(WaveformModel):
 
     def annotate_window_post(self, pred, piggyback=None, argdict=None):
         # Combine predictions in one array
-        prenan, postnan = argdict.get("blinding", (0, 0))
+        prenan, postnan = argdict.get(
+            "blinding", self._annotate_args.get("blinding")[1]
+        )
         pred = np.stack(pred, axis=-1)
         if prenan > 0:
             pred[:prenan] = np.nan
@@ -275,13 +300,17 @@ class EQTransformer(WaveformModel):
         for phase in self.phases:
             picks += self.picks_from_annotations(
                 annotations.select(channel=f"EQTransformer_{phase}"),
-                argdict.get(f"{phase}_threshold", 0.1),
+                argdict.get(
+                    f"{phase}_threshold", self._annotate_args.get("*_threshold")[1]
+                ),
                 phase,
             )
 
         detections = self.detections_from_annotations(
             annotations.select(channel="EQTransformer_Detection"),
-            argdict.get("detection_threshold", 0.3),
+            argdict.get(
+                "detection_threshold", self._annotate_args.get("detection_threshold")[1]
+            ),
         )
 
         return sorted(picks), sorted(detections)
