@@ -1,11 +1,19 @@
-from .base import WaveformModel
-
+import numpy as np
 import torch
 import torch.nn as nn
-import numpy as np
+
+from .base import WaveformModel
 
 
 class GPD(WaveformModel):
+    """
+    .. document_args:: seisbench.models GPD
+    """
+
+    _annotate_args = WaveformModel._annotate_args.copy()
+    _annotate_args["*_threshold"] = ("Detection threshold for the provided phase", 0.7)
+    _annotate_args["stride"] = (_annotate_args["stride"][0], 10)
+
     def __init__(
         self,
         in_channels=3,
@@ -29,7 +37,6 @@ class GPD(WaveformModel):
             pred_sample=pred_sample,
             labels=phases,
             sampling_rate=sampling_rate,
-            default_args={"stride": 10},
             **kwargs,
         )
 
@@ -62,7 +69,7 @@ class GPD(WaveformModel):
 
         self.pool = nn.MaxPool1d(2, 2)
 
-    def forward(self, x):
+    def forward(self, x, logits=False):
         # Max normalization
         x = x / (
             torch.max(
@@ -84,10 +91,13 @@ class GPD(WaveformModel):
         x = self.activation(self.bn6(self.fc2(x)))
         x = self.fc3(x)
 
-        if self.classes == 1:
-            return torch.sigmoid(x)
+        if logits:
+            return x
         else:
-            return torch.softmax(x, -1)
+            if self.classes == 1:
+                return torch.sigmoid(x)
+            else:
+                return torch.softmax(x, -1)
 
     @property
     def phases(self):
@@ -118,7 +128,9 @@ class GPD(WaveformModel):
 
             picks += self.picks_from_annotations(
                 annotations.select(channel=f"GPD_{phase}"),
-                argdict.get(f"{phase}_threshold", 0.7),
+                argdict.get(
+                    f"{phase}_threshold", self._annotate_args.get("*_threshold")[1]
+                ),
                 phase,
             )
 
